==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/EditRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditRowDefinitionDescription } from "./EditRowDefinitionDescription";
/**
 * @hidden
 */
var EditRowDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EditRowDefinitionDescriptionMetadata, _super);
    function EditRowDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditRowDefinitionDescriptionMetadata.b = function (a) {
        if (EditRowDefinitionDescriptionMetadata.a == null) {
            EditRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditRowDefinitionDescriptionMetadata.c(EditRowDefinitionDescriptionMetadata.a);
        }
        if (a.k(EditRowDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.ab(EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    EditRowDefinitionDescriptionMetadata.d = function (a) {
        EditRowDefinitionDescriptionMetadata.b(a);
        a.ad("EditRowDefinition", function () { return new EditRowDefinitionDescription(); });
        a.ac("EditRowDefinition", EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.$t = markType(EditRowDefinitionDescriptionMetadata, 'EditRowDefinitionDescriptionMetadata');
    EditRowDefinitionDescriptionMetadata.a = null;
    return EditRowDefinitionDescriptionMetadata;
}(Base));
export { EditRowDefinitionDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/EditRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditRowDefinitionDescription } from "./EditRowDefinitionDescription";
/**
 * @hidden
 */
var EditRowDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EditRowDefinitionDescriptionMetadata, _super);
    function EditRowDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditRowDefinitionDescriptionMetadata.b = function (a) {
        if (EditRowDefinitionDescriptionMetadata.a == null) {
            EditRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditRowDefinitionDescriptionMetadata.c(EditRowDefinitionDescriptionMetadata.a);
        }
        if (a.k(EditRowDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.ac(EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    EditRowDefinitionDescriptionMetadata.d = function (a) {
        EditRowDefinitionDescriptionMetadata.b(a);
        a.ae("EditRowDefinition", function () { return new EditRowDefinitionDescription(); });
        a.ad("EditRowDefinition", EditRowDefinitionDescriptionMetadata.a);
    };
    EditRowDefinitionDescriptionMetadata.$t = markType(EditRowDefinitionDescriptionMetadata, 'EditRowDefinitionDescriptionMetadata');
    EditRowDefinitionDescriptionMetadata.a = null;
    return EditRowDefinitionDescriptionMetadata;
}(Base));
export { EditRowDefinitionDescriptionMetadata };
